@@ -1,8 +1,8 @@
 # $File: //member/autrijus/Module-Signature/Signature.pm $ 
-# $Revision: #21 $ $Change: 1352 $ $DateTime: 2002/10/12 10:42:09 $
+# $Revision: #22 $ $Change: 1370 $ $DateTime: 2002/10/12 18:55:39 $
 
 package Module::Signature;
-$Module::Signature::VERSION = '0.10';
+$Module::Signature::VERSION = '0.11';
 
 use strict;
 use vars qw($VERSION $SIGNATURE @ISA @EXPORT_OK);
@@ -50,7 +50,7 @@ Module::Signature - Module signature file manipulation
 
 =head1 VERSION
 
-This document describes version 0.10 of B<Module::Signature>.
+This document describes version 0.11 of B<Module::Signature>.
 
 =head1 SYNOPSIS
 
@@ -242,7 +242,7 @@ sub _verify_gpg {
 	    "--keyserver=$KeyServer",
 	    ($version ge "1.0.7")
 		? "--keyserver-options=auto-key-retrieve"
-		: "--auto-key-retrieve",
+		: ''
 	) : ()), $SIGNATURE,
     );
 
